===========================================
Ubuntu PPA Package Version Report
===========================================


.. image:: https://img.shields.io/pypi/v/ubuntu_ppa_package_version_report.svg
        :target: https://pypi.python.org/pypi/ubuntu_ppa_package_version_report

.. image:: https://img.shields.io/travis/philroche/ubuntu_ppa_package_version_report.svg
        :target: https://travis-ci.com/philroche/ubuntu_ppa_package_version_report


Utility to Generate a report on the versions of packages in specified PPAs

* Free software: GNU General Public License v3



Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
